import { css } from "@emotion/react";
import styled from "@emotion/styled";
import { faSpinner } from "@fortawesome/free-solid-svg-icons";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import React from "react";
export const VariantPicker = ({ loading, variants: allVariants, componentName, currentVariantKey, onClick, onVariantSelected, }) => {
    const variants = allVariants === null || allVariants === void 0 ? void 0 : allVariants.filter((v) => !v.isEditorDriven);
    return (React.createElement(Container, { onClick: onClick },
        React.createElement(ComponentLabel, null, componentName),
        !variants ? (React.createElement(ComponentSpinnerIcon, { icon: faSpinner, spin: true })) : (variants.length > 0 && (React.createElement(VariantList, { id: "variant-list" }, variants.map((v) => {
            const selected = currentVariantKey === v.key;
            return (React.createElement(VariantItem, { key: v.key, "$selected": selected, className: "variant", id: selected ? "selected-variant" : undefined, onClick: (e) => {
                    onVariantSelected(v.key);
                    e.stopPropagation();
                } }, v.label));
        }))))));
};
const Container = styled.div `
  display: inline-flex;
  align-items: center;
  cursor: pointer;
  padding: 4px 8px;
  border-radius: 16px;
  margin-right: 8px;
  color: hsl(213, 20%, 70%);
  font-size: 1rem;
  background: hsl(213, 60%, 95%);
  color: hsl(213, 60%, 30%);
  user-select: none;
`;
const ComponentSpinnerIcon = styled(FontAwesomeIcon) `
  color: hsl(213, 60%, 20%);
  margin-left: 8px;
`;
const ComponentLabel = styled.div `
  display: inline-flex;
  align-items: center;
  padding: 2px 0;
`;
const VariantList = styled.div `
  display: inline-flex;
  margin-left: 8px;
  margin-right: -4px;
  border-radius: 16px;
  background: hsl(213, 40%, 80%);
`;
const VariantItem = styled.div `
  cursor: pointer;
  padding: 3px 8px 1px 8px;
  font-size: 0.9rem;
  font-weight: 600;
  color: hsl(213, 40%, 50%);
  ${({ $selected }) => $selected &&
    css `
      color: hsl(213, 80%, 10%);
    `}
  &:hover {
    ${({ $selected }) => !$selected &&
    css `
        color: hsl(213, 60%, 30%);
      `}
`;
